.. include:: ../README.md
   :parser: myst_parser.sphinx_

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Getting Started

   build-instructions

.. toctree::
   :maxdepth: 2
   :hidden:
   :titlesonly:
   :caption: Interfaces

   tree/interfaces-overview
   tree/cpp-interface
   tree/python-interface

.. toctree::
   :maxdepth: 2
   :hidden:
   :titlesonly:
   :caption: Examples

   tree/python-demos

.. toctree::
    :maxdepth: 2
    :hidden:
    :titlesonly:
    :caption: Technicalities

    tree/lobes
    tree/station-hierarchy

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Indices and Tables

   indices-and-tables